@@ -11,7 +11,7 @@ use Const::Fast ();
 use Keyword::Simple;
 use Text::Balanced ();
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.2.0';
 
 
 sub import {
@@ -42,7 +42,24 @@ sub _rewrite_let {
             $$ref =~ s/^\S+//;
         }
 
-        $let .= "Const::Fast::const my $name => $val;\n";
+        if ($] >= 5.028 || substr($name, 0, 1) eq '$') {
+
+            # We can't use Const::Fast on state variables, so we use
+            # this workaround.
+
+            $let .= << "HERE"
+use feature 'state';
+state $name = $val;
+unless (state \$set = 0) { Const::Fast::_make_readonly($name); \$set = 1; };
+HERE
+
+        }
+        else {
+
+            $let .= "Const::Fast::const my $name => $val;\n";
+        }
+
+
 
     } while ( $$ref =~ s/^\s*,\s*// );
 
@@ -76,7 +93,7 @@ PerlX::Let - Syntactic sugar for lexical constants
 
 =head1 VERSION
 
-version v0.1.0
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -94,19 +111,39 @@ version v0.1.0
 
 =head1 DESCRIPTION
 
-The code
+This module allows you to define lexical constants using a new C<let>
+keyword, for example, code such as
 
-  let $var = "thing" { ... }
+  if (defined $arg{username}) {
+    $row->update( { username => $arg{username} );
+  }
 
-is shorthand for
+is liable to typos. You could simplify it with
+
+  let $key = "username" {
+
+    if (defined $arg{$key}) {
+      $row->update( { $key => $arg{$key} );
+    }
+
+  }
+
+This is roughly equivalent to using
+
+  use Const::Fast;
 
   {
-     use Const::Fast;
-     const my $var => "thing";
+   const $key => "username";
+
+    if (defined $arg{$key}) {
+      $row->update( { $key => $arg{$key} );
+    }
 
-     ...
   }
 
+However, if the variable is a scalar, or you are using Perl v5.28 or
+later, this uses state variables so that the value is only set once.
+
 =head1 KNOWN ISSUES
 
 This is an experimental version.
@@ -116,6 +153,8 @@ to another variable or the result of a function.
 
 =head1 SEE ALSO
 
+L<Const::Fast>
+
 L<Keyword::Simple>
 
 =head1 AUTHOR
